@@ -1,6 +1,6 @@
 // Filename: lib.rs
-// Version:	 0.14
-// Date:	 30-12-2021 (DD-MM-YYYY)
+// Version:	 0.15
+// Date:	 01-01-2021 (DD-MM-YYYY)
 // Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
@@ -35,7 +35,7 @@ use gpcas_isa::Isa;
 use serde::{Deserialize, Serialize};
 use std::iter::once;
 
-pub use validation::{validate, FailedValidation, ValidationError};
+pub use validation::{validate, BranchPredictionError, FailedValidation, ValidationError};
 
 /// The configuration of an abstract CPU model.
 #[derive(Clone, Default, Deserialize, Serialize)]
